@@ -1,7 +1,7 @@
 // qjackctlAboutForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,12 +22,6 @@
 #ifndef __qjackctlAboutForm_h
 #define __qjackctlAboutForm_h
 
-#include <QtGlobal>
-
-#if QT_VERSION < 0x040200
-#define setOpenExternalLinks(x) parent()
-#endif
-
 #include "ui_qjackctlAboutForm.h"
 
 
