@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -49,19 +49,26 @@ class qjackctlPortItem : public QTreeWidgetItem
 public:
 
 	// Constructor.
-	qjackctlPortItem(qjackctlClientItem *pClient, const QString& sPortName);
+	qjackctlPortItem(qjackctlClientItem *pClient);
 	// Default destructor.
-	~qjackctlPortItem();
+	virtual ~qjackctlPortItem();
 
 	// Instance accessors.
 	void setPortName(const QString& sPortName);
 	const QString& clientName() const;
 	const QString& portName() const;
 
+	// Port name alias accessors.
+	void setPortNameAlias(const QString& sPortNameAlias);
+	QString portNameAlias(bool *pbRenameEnabled) const;
+
+	// Proto-pretty/display name accessors.
+	virtual void updatePortName(bool bRename = false);
+
 	// Complete client:port name helper.
 	QString clientPortName() const;
 
-	// Connections client item accessor.
+	// Connections client item method.
 	qjackctlClientItem *client() const;
 
 	// Client port cleanup marker.
@@ -89,6 +96,12 @@ public:
 	// - Natural decimal sorting comparator.
 	bool operator< (const QTreeWidgetItem& other) const;
 
+protected:
+
+	// Port name display name accessors.
+	void setPortText(const QString& sPortText, bool bRenameEnabled);
+	QString portText() const;
+
 private:
 
 	// Instance variables.
@@ -109,10 +122,9 @@ class qjackctlClientItem : public QTreeWidgetItem
 public:
 
 	// Constructor.
-	qjackctlClientItem(qjackctlClientList *pClientList,
-		const QString& sClientName);
+	qjackctlClientItem(qjackctlClientList *pClientList);
 	// Default destructor.
-	~qjackctlClientItem();
+	virtual ~qjackctlClientItem();
 
 	// Port list primitive methods.
 	void addPort(qjackctlPortItem *pPort);
@@ -125,6 +137,13 @@ public:
 	void setClientName(const QString& sClientName);
 	const QString& clientName() const;
 
+	// Client name alias accessors.
+	void setClientNameAlias(const QString& sClientNameAlias);
+	QString clientNameAlias(bool *pbRenameEnabled) const;
+
+	// Proto-pretty/display name method.
+	virtual void updateClientName(bool bRename = false);
+
 	// Readable flag accessor.
 	bool isReadable() const;
 
@@ -152,6 +171,12 @@ public:
 	// - Natural decimal sorting comparator.
 	bool operator< (const QTreeWidgetItem& other) const;
 
+protected:
+
+	// Client name display name accessors.
+	void setClientText(const QString& sClientText, bool bRenameEnabled);
+	QString clientText() const;
+
 private:
 
 	// Instance variables.
@@ -245,11 +270,15 @@ public:
 	// Aliasing support methods.
 	void setAliases(qjackctlConnectAlias *pAliases, bool bRenameEnabled);
 	qjackctlConnectAlias *aliases() const;
-	bool renameEnabled() const;
+	bool isRenameEnabled() const;
 
 	// Binding indirect accessor.
 	qjackctlConnect *binding() const;
 
+	// Dirty flag accessors.
+	void setDirty (bool bDirty);
+	bool isDirty() const;
+
 protected slots:
 
 	// In-place aliasing slots.
