@@ -1,7 +1,7 @@
 // qjackctlMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -182,6 +182,7 @@ protected:
 	void updateConnectionsFont();
 	void updateConnectionsIconSize();
 	void updateJackClientPortAlias();
+	void updateJackClientPortMetadata();
 	void updateBezierLines();
 	void updateDisplayEffect();
 	void updateTimeDisplayFonts();
@@ -201,6 +202,9 @@ protected:
 	void buffNotifyEvent();
 	void shutNotifyEvent();
 	void exitNotifyEvent();
+#ifdef CONFIG_JACK_METADATA
+	void propNotifyEvent();
+#endif
 
 	void startJackClientDelay();
 	bool startJackClient(bool bDetach);
@@ -288,6 +292,10 @@ private:
 	int m_iStatusRefresh;
 	int m_iPatchbayRefresh;
 
+#ifdef CONFIG_JACK_METADATA
+	int m_iJackPropertyChange;
+#endif
+
 	QSocketNotifier *m_pStdoutNotifier;
 	QSocketNotifier *m_pAlsaNotifier;
 
