@@ -1,7 +1,7 @@
 // qjackctlPatchbayFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -45,12 +45,7 @@ static void load_socketlist ( QList<qjackctlPatchbaySocket *>& socketlist,
 			QString sSocketType = eSocket.attribute("type");
 			QString sExclusive  = eSocket.attribute("exclusive");
 			QString sSocketForward = eSocket.attribute("forward");
-			int iSocketType = QJACKCTL_SOCKETTYPE_JACK_AUDIO;
-			if (sSocketType == "midi" || sSocketType == "alsa-midi")
-				iSocketType = QJACKCTL_SOCKETTYPE_ALSA_MIDI;
-			else
-			if (sSocketType == "jack-midi")
-				iSocketType = QJACKCTL_SOCKETTYPE_JACK_MIDI;
+			int iSocketType = qjackctlPatchbaySocket::typeFromText(sSocketType);
 			bool bExclusive = (sExclusive == "on" || sExclusive == "yes" || sExclusive == "1");
 			qjackctlPatchbaySocket *pSocket
 				= new qjackctlPatchbaySocket(sSocketName, sClientName, iSocketType);
@@ -86,13 +81,8 @@ static void save_socketlist ( QList<qjackctlPatchbaySocket *>& socketlist,
 		QDomElement eSocket = doc.createElement("socket");
 		eSocket.setAttribute("name", pSocket->name());
 		eSocket.setAttribute("client", pSocket->clientName());
-		QString sSocketType = "audio";	// FIXME: "jack-audio"
-		if (pSocket->type() == QJACKCTL_SOCKETTYPE_ALSA_MIDI)
-			sSocketType = "midi";		// FIXME: "alsa-midi"
-		else
-		if (pSocket->type() == QJACKCTL_SOCKETTYPE_JACK_MIDI)
-			sSocketType = "jack-midi";
-		eSocket.setAttribute("type", sSocketType);
+		eSocket.setAttribute("type",
+			qjackctlPatchbaySocket::textFromType(pSocket->type()));
 		eSocket.setAttribute("exclusive", (pSocket->isExclusive() ? "on" : "off"));
 		if (!pSocket->forward().isEmpty())
 			eSocket.setAttribute("forward", pSocket->forward());
@@ -194,12 +184,15 @@ bool qjackctlPatchbayFile::load ( qjackctlPatchbayRack *pPatchbay,
 				if (eCable.isNull())
 					continue;
 				if (eCable.tagName() == "cable") {
+					int iSocketType
+						= qjackctlPatchbaySocket::typeFromText(
+							eCable.attribute("type"));
 					qjackctlPatchbaySocket *pOutputSocket
 						= pPatchbay->findSocket(pPatchbay->osocketlist(),
-							eCable.attribute("output"));
+							eCable.attribute("output"), iSocketType);
 					qjackctlPatchbaySocket *pIntputSocket
 						= pPatchbay->findSocket(pPatchbay->isocketlist(),
-							eCable.attribute("input"));
+							eCable.attribute("input"), iSocketType);
 					if (pOutputSocket && pIntputSocket) {
 						pPatchbay->addCable(
 							new qjackctlPatchbayCable(
@@ -270,6 +263,9 @@ bool qjackctlPatchbayFile::save ( qjackctlPatchbayRack *pPatchbay,
 		qjackctlPatchbayCable *pCable = cablit.next();
 		if (pCable->outputSocket() && pCable->inputSocket()) {
 			QDomElement eCable = doc.createElement("cable");
+			eCable.setAttribute("type",
+				qjackctlPatchbaySocket::textFromType(
+					pCable->outputSocket()->type()));
 			eCable.setAttribute("output", pCable->outputSocket()->name());
 			eCable.setAttribute("input", pCable->inputSocket()->name());
 			eCables.appendChild(eCable);
