@@ -1,7 +1,7 @@
 // qjackctlSession.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,6 +27,9 @@
 
 #include <jack/jack.h>
 
+// Forward decls.
+class QSettings;
+
 
 //----------------------------------------------------------------------------
 // qjackctlSession -- JACK session container.
@@ -93,6 +96,28 @@ public:
 	// Update (re)connections utility method.
 	bool update();
 
+	// Infra-client table.
+	struct InfraClientItem
+	{
+		QString  client_name;
+		QString  client_command;
+	};
+
+	typedef QHash<QString, InfraClientItem *> InfraClientList;
+
+	// Infra-client list accessor (read-write)
+	InfraClientList& infra_clients();
+
+	// Load/save all infra-clients from/to configuration file.
+	void loadInfraClients(QSettings& settings);
+	void saveInfraClients(QSettings& settings);
+
+	// Clear infra-client table.
+	void clearInfraClients();
+
+	// Check whether a given JACK client name exists...
+	bool isJackClient(const QString& sClientName) const;
+
 protected:
 
 	// File methods.
@@ -103,6 +128,9 @@ private:
 
 	// Instance variables.
 	ClientList m_clients;	
+
+	// Infra-clients table.
+	InfraClientList m_infra_clients;
 };
 
 
