@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ qjackctlSetup::qjackctlSetup (void)
 // Destructor;
 qjackctlSetup::~qjackctlSetup (void)
 {
-	saveSetup();
+//	saveSetup();
 }
 
 
@@ -104,6 +104,7 @@ void qjackctlSetup::loadSetup (void)
 	bDisplayEffect           = m_settings.value("/DisplayEffect", true).toBool();
 	bDisplayBlink            = m_settings.value("/DisplayBlink", true).toBool();
 	iJackClientPortAlias     = m_settings.value("/JackClientPortAlias", 0).toInt();
+	bJackClientPortMetadata  = m_settings.value("/JackClientPortMetadata", false).toBool();
 	iConnectionsIconSize     = m_settings.value("/ConnectionsIconSize", QJACKCTL_ICON_16X16).toInt();
 	sConnectionsFont         = m_settings.value("/ConnectionsFont").toString();
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
@@ -215,6 +216,7 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/DisplayEffect",           bDisplayEffect);
 	m_settings.setValue("/DisplayBlink",            bDisplayBlink);
 	m_settings.setValue("/JackClientPortAlias",     iJackClientPortAlias);
+	m_settings.setValue("/JackClientPortMetadata",  bJackClientPortMetadata);
 	m_settings.setValue("/ConnectionsIconSize",     iConnectionsIconSize);
 	m_settings.setValue("/ConnectionsFont",         sConnectionsFont);
 	m_settings.setValue("/QueryClose",              bQueryClose);
